@@ -5,13 +5,13 @@ def top_csv(df, csv):
     col_names = show_col_names(df)
 
     while True:
-        col_name = input('想要按照哪一列进行TOP? :')
+        col_name = input('\n想要按照哪一列进行TOP? :')
         if col_name in col_names:
             break
         else:
             print('列名错误，请重新输入')
     while True:
-        print('[1.升序(值越小越好)]或[2.降序(值越大越好)]')
+        print('\n[1.升序(值越小越好)]或[2.降序(值越大越好)]')
         assending_num = input('请输入1或2选择排列方式：')
         if assending_num == '1':
             assending = True
